"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.stat = exports.remove = exports.pathExists = exports.copy = void 0;
const fs_1 = require("fs");
const path_1 = require("path");
const exec_1 = require("./exec");
const log_1 = require("./log");
async function mkdirP(src) {
    (0, log_1.verbose)(`mkdir -p ${src}`);
    await (0, exec_1.exec)('mkdir', ['-p', src]);
}
function copy(src, target) {
    return mkdirP((0, path_1.dirname)(target)).then(() => {
        return new Promise((resolve, reject) => {
            (0, log_1.verbose)(`fs.copyFile(${src}, ${target})`);
            (0, fs_1.copyFile)(src, target, (err) => (err ? reject(err) : resolve()));
        });
    });
}
exports.copy = copy;
function pathExists(src) {
    return new Promise((resolve) => {
        (0, log_1.verbose)(`fs.access(${src}, ${fs_1.constants.F_OK})`);
        (0, fs_1.access)(src, fs_1.constants.F_OK, (err) => (err ? resolve(false) : resolve(true)));
    });
}
exports.pathExists = pathExists;
async function remove(src) {
    (0, log_1.verbose)(`rm -rf ${src}`);
    await (0, exec_1.exec)('rm', ['-rf', src]);
}
exports.remove = remove;
function stat(src) {
    return new Promise((resolve, reject) => {
        (0, log_1.verbose)(`fs.stat(${src})`);
        (0, fs_1.stat)(src, (err, stats) => (err ? reject(err) : resolve(stats)));
    });
}
exports.stat = stat;
