"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getStats = void 0;
const fs_1 = require("./fs");
const filesize_1 = require("./filesize");
const getFileSize = async (filePath) => {
    const { size } = await (0, fs_1.stat)(filePath);
    return size;
};
const getPercentOf = (whole, part) => (part ? (part / whole) * 100 : 0);
const createStat = (label, sizeAfter, sizeBefore) => {
    const sizeSaving = sizeBefore - sizeAfter;
    return {
        path: label,
        pretty: {
            after: (0, filesize_1.formatFilesize)(sizeAfter),
            before: (0, filesize_1.formatFilesize)(sizeBefore),
            saving: (0, filesize_1.formatFilesize)(sizeSaving),
        },
        raw: {
            after: sizeAfter,
            before: sizeBefore,
            percentSaving: getPercentOf(sizeBefore, sizeSaving),
            saving: sizeSaving,
        },
    };
};
const getStats = async (options) => {
    const fileStats = await Promise.all(options.filePaths.map(async ({ source, tmp }) => {
        const sizeBefore = await getFileSize(source);
        const sizeAfter = await getFileSize(tmp);
        return createStat(source, sizeAfter, sizeBefore);
    }));
    const totalStats = fileStats.reduce((total, file) => {
        const sizeAfter = total.raw.after + file.raw.after;
        const sizeBefore = total.raw.before + file.raw.before;
        return createStat('TOTAL', sizeAfter, sizeBefore);
    }, createStat('TOTAL', 0, 0));
    return {
        files: fileStats,
        total: totalStats,
    };
};
exports.getStats = getStats;
