#!@@HOMEBREW_PREFIX@@/opt/node/bin/node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const commander_1 = require("commander");
const globby_1 = require("globby");
const os_1 = require("os");
const _1 = require("./");
const constants_1 = require("./constants");
const patterns = [];
commander_1.program
    .version(constants_1.VERSION)
    .arguments('[patterns...]')
    .action((args) => {
    patterns.push(...args.filter((arg) => arg && typeof arg === 'string'));
})
    .option('-a, --imagealpha', 'enable ImageAlpha')
    .option('-j, --jpegmini', 'enable JPEGmini')
    .option('-C, --no-color', 'output to the terminal without colors')
    .option('-I, --no-imageoptim', 'disable ImageOptim')
    .option('-Q, --no-quit', 'do not quit apps once finished')
    .option('-S, --no-stats', 'do not display file size savings and quality loss information')
    .option('--number-of-colors <n>', `ImageAlpha palette size, defaults to ${constants_1.PNGQUANT_NUMBER_OF_COLORS}`)
    .option('--quality <min>-<max>', `ImageAlpha quality range from 0-100, defaults to ${constants_1.PNGQUANT_QUALITY}`)
    .option('--speed <n>', `ImageAlpha speed from 1 (brute-force) to 10 (fastest), defaults to ${constants_1.PNGQUANT_SPEED}`);
commander_1.program.on('--help', () => {
    console.log(`
  Supported Apps:

    ImageAlpha: ${chalk_1.default.blue.underline('https://pngmini.com')}
    ImageOptim: ${chalk_1.default.blue.underline('https://imageoptim.com')}
    JPEGmini Lite: ${chalk_1.default.blue.underline('https://itunes.apple.com/us/app/jpegmini-lite/id525742250')}
    JPEGmini Pro: ${chalk_1.default.blue.underline('https://itunes.apple.com/us/app/jpegmini-pro/id887163276')}
    JPEGmini: ${chalk_1.default.blue.underline('https://itunes.apple.com/us/app/jpegmini/id498944723')}

  Examples:

    ${chalk_1.default.dim('Run ImageOptim.app over every image in current directory')}
    imageoptim

    ${chalk_1.default.dim('Run ImageAlpha.app and ImageOptim.app over every PNG in current directory')}
    imageoptim --imagealpha '**/*.png'

    ${chalk_1.default.dim('Run JPEGmini.app and ImageOptim.app over every JPG in current directory')}
    imageoptim --jpegmini '**/*.jpg' '**/*.jpeg'

    ${chalk_1.default.dim('Run JPEGmini.app over every JPG in current directory')}
    imageoptim --jpegmini --no-imageoptim '**/*.jpg' '**/*.jpeg'

    ${chalk_1.default.dim('Run ImageOptim.app over every image in a specific directory')}
    imageoptim '~/Desktop'
    `.trimRight());
});
commander_1.program.parse(process.argv);
if (process.platform !== 'darwin') {
    console.log('imageoptim-cli is macOS only');
}
const supportedTypesPattern = constants_1.SUPPORTED_FILE_TYPES.map((fileType) => `*${fileType}`).join('|');
patterns.push(`!**/!(${supportedTypesPattern})`);
const filePaths = (0, globby_1.sync)(patterns.map((pattern) => pattern.replace('~', (0, os_1.homedir)())));
const options = commander_1.program.opts();
(0, _1.cli)({
    batchSize: 300,
    enabled: {
        color: options.color === true,
        imageAlpha: options.imagealpha === true,
        imageOptim: options.imageoptim === true,
        jpegMini: options.jpegmini === true,
        quit: options.quit === true,
        stats: options.stats === true,
    },
    filePaths,
    numberOfColors: options.numberOfColors || constants_1.PNGQUANT_NUMBER_OF_COLORS,
    quality: options.quality || constants_1.PNGQUANT_QUALITY,
    speed: options.speed || constants_1.PNGQUANT_SPEED,
    tmpDir: constants_1.TMPDIR,
});
