"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.cli = void 0;
const path_1 = require("path");
const get_stats_1 = require("./get-stats");
const log_1 = require("./log");
const run_imagealpha_1 = require("./run-imagealpha");
const run_imageoptim_1 = require("./run-imageoptim");
const run_jpegmini_1 = require("./run-jpegmini");
const tmpdir_1 = require("./tmpdir");
const write_report_1 = require("./write-report");
const runnersByName = {
    imageAlpha: run_imagealpha_1.runImageAlpha,
    imageOptim: run_imageoptim_1.runImageOptim,
    jpegMini: run_jpegmini_1.runJpegMini,
    stats: get_stats_1.getStats,
};
const cloneArray = (array) => [...array];
const runIfEnabled = (key, options) => options.enabled[key] ? runnersByName[key](options) : Promise.resolve();
const processBatch = async (options) => {
    await (0, tmpdir_1.setup)(options);
    await Promise.all([runIfEnabled('imageAlpha', options), runIfEnabled('jpegMini', options)]);
    await runIfEnabled('imageOptim', options);
    const stats = await runIfEnabled('stats', options);
    await (0, tmpdir_1.tearDown)(options);
    if (stats) {
        await (0, write_report_1.writeReport)(stats);
    }
};
const cli = async (options) => {
    try {
        const filesMutable = cloneArray(options.filePaths);
        (0, log_1.enableColor)(options.enabled.color);
        if (filesMutable.length === 0) {
            return (0, log_1.warning)('No images matched the patterns provided');
        }
        while (filesMutable.length > 0) {
            const filePaths = filesMutable.splice(0, options.batchSize);
            await processBatch({
                batchSize: options.batchSize,
                enabled: options.enabled,
                filePaths: filePaths.map((filePath) => ({
                    source: filePath,
                    tmp: (0, path_1.join)(options.tmpDir, filePath),
                })),
                numberOfColors: options.numberOfColors,
                quality: options.quality,
                speed: options.speed,
                tmpDir: options.tmpDir,
            });
        }
        (0, log_1.complete)('Finished');
    }
    catch (err) {
        (0, log_1.bug)(err);
        await (0, tmpdir_1.clean)(options);
    }
};
exports.cli = cli;
