"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.enableColor = exports.verbose = exports.result = exports.panic = exports.bug = exports.warning = exports.info = exports.complete = void 0;
const chalk_1 = __importDefault(require("chalk"));
const util_1 = require("util");
const tmpdir_1 = require("./tmpdir");
let color = new chalk_1.default.Instance({ level: 3 });
const complete = (value) => console.log(color.green('✓ %s'), value);
exports.complete = complete;
const info = (value) => console.log(color.blue('i %s'), value);
exports.info = info;
const warning = (value) => console.log(color.yellow('! %s'), value);
exports.warning = warning;
const bug = (err) => {
    if (util_1.types.isNativeError(err)) {
        console.log(color.red('! %s\n\n! Please raise an issue at %s\n\n%s'), err.message, color.underline('https://github.com/JamieMason/ImageOptim-CLI/issues'), String(err.stack).replace(/^/gm, '    '));
    }
    else {
        console.log(color.red('! %s\n\n! Please raise an issue at %s'), err, color.underline('https://github.com/JamieMason/ImageOptim-CLI/issues'));
    }
    process.exit(1);
};
exports.bug = bug;
const panic = async (value, options) => {
    console.log(color.red('! %s'), value);
    await (0, tmpdir_1.clean)(options);
    process.exit(1);
};
exports.panic = panic;
const result = (label = 'TOTAL', prettySizeBefore, prettySizeAfter, prettySizeSaving, sizeSavingPercent) => {
    console.log('%s %s was: %s now: %s saving: %s (%s)', color.green('✓'), chalk_1.default.underline(label), color.red(prettySizeBefore), color.green(prettySizeAfter), color.green(prettySizeSaving), color.green(`${sizeSavingPercent.toFixed(2)}%`));
};
exports.result = result;
exports.verbose = process.env.NODE_ENV === 'development'
    ? (value) => console.info(color.grey('? %s'), value)
    : () => undefined;
const enableColor = (enabled) => {
    color = new chalk_1.default.Instance({ level: enabled ? 3 : 0 });
};
exports.enableColor = enableColor;
