"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.runJpegMini = void 0;
const applescript_1 = require("./applescript");
const constants_1 = require("./constants");
const log_1 = require("./log");
const runJpegMini = async (options) => {
    (0, log_1.verbose)('Locating JPEGmini installation');
    const jpegMini = (0, applescript_1.getJpegMini)();
    (0, log_1.verbose)('Checking support for assistive devices');
    const assistiveDeviceSupport = (0, applescript_1.supportsAssistiveDevices)();
    const [app, canAutomate] = await Promise.all([jpegMini, assistiveDeviceSupport]);
    if (!app) {
        return (0, log_1.panic)(`JPEGmini is not installed (${constants_1.JPEG_MINI_URL})`, options);
    }
    if (!canAutomate) {
        return (0, log_1.panic)(`Support for assistive devices needed, see ${constants_1.ASSISTIVE_DEVICES_URL}`, options);
    }
    (0, log_1.info)(`Running ${app.name}...`);
    await (0, applescript_1.runJpegMini)(app);
    if (options.enabled.quit) {
        (0, log_1.verbose)(`Quitting ${app.name}`);
        await (0, applescript_1.quitApp)(app);
    }
    (0, log_1.verbose)(`${app.name} has finished`);
};
exports.runJpegMini = runJpegMini;
